@@ -13,7 +13,9 @@
 #' @param Var_vec Vector of variables to aggregate. If NULL (default) all the variables are averaged,
 #' expect for 'Temperature' and 'Snow_height' which are summed.
 #' @param Fns_vec Vector of aggregation function to apply to the selected variables. Available functions
-#'  are mean, median, min, max, sum and qXX for the XX_th percentile.
+#'  are mean, median, min, max, sum, qPP (PP-th percentile), sd, var, vc (variability coefficient),
+#'  skew (skewness) and kurt (kurtosis). Attention: for Wind Speed and Wind Speed Gust only mean, min
+#'  and max are available; for Wind Direction and Wind Direction Gust only mean is available.
 #' @param verbose Logic value (T or F). Toggle warnings and messages. If 'verbose=T' (default) the function
 #' prints on the screen some messages describing the progress of the tasks. If 'verbose=F' any message about
 #' the progression is suppressed.
@@ -144,7 +146,11 @@ Time_aggregate <- function(Dataset, Frequency, Var_vec = NULL, Fns_vec = NULL, v
   structure(list(data_aggr = data_aggr))
   if (is_ARPALdf_AQ(Dataset)==T) {
     attr(data_aggr, "class") <- c("ARPALdf","ARPALdf_AQ","tbl_df","tbl","data.frame")
-  } else if (is_ARPALdf_W(Dataset)==T) {
+  }
+  if (is_ARPALdf_AQ_mun(Dataset)==T) {
+    attr(data_aggr, "class") <- c("ARPALdf","ARPALdf_AQ_mun","tbl_df","tbl","data.frame")
+  }
+  if (is_ARPALdf_W(Dataset)==T) {
     attr(data_aggr, "class") <- c("ARPALdf","ARPALdf_W","tbl_df","tbl","data.frame")
   }
   return(data_aggr)
